@@ -29,14 +29,14 @@ namespace itk
 MoreThuenteLineSearchOptimizer
 ::MoreThuenteLineSearchOptimizer()
 {
-  this->m_f = NumericTraits<MeasureType>::Zero;
-  this->m_dg = 0.0;
+  this->m_f                         = NumericTraits< MeasureType >::Zero;
+  this->m_dg                        = 0.0;
   this->m_InitialDerivativeProvided = false;
-  this->m_InitialValueProvided = false;
+  this->m_InitialValueProvided      = false;
   this->m_MaximumNumberOfIterations = 20;
-  this->m_ValueTolerance = 1e-4;
-  this->m_GradientTolerance = 0.9;
-  this->m_IntervalTolerance = std::numeric_limits<double>::epsilon();
+  this->m_ValueTolerance            = 1e-4;
+  this->m_GradientTolerance         = 0.9;
+  this->m_IntervalTolerance         = std::numeric_limits< double >::epsilon();
   this->SetMinimumStepLength( 1e-20 );
   this->SetMaximumStepLength( 1e20 );
 
@@ -54,7 +54,7 @@ MoreThuenteLineSearchOptimizer
 ::SetInitialValue( MeasureType value )
 {
   this->m_InitialValueProvided = true;
-  this->m_f = value;
+  this->m_f                    = value;
   this->Modified();
 
 } // end SetInitialValue()
@@ -69,7 +69,7 @@ MoreThuenteLineSearchOptimizer
 ::SetInitialDerivative( const DerivativeType & derivative )
 {
   this->m_InitialDerivativeProvided = true;
-  this->m_g = derivative;
+  this->m_g                         = derivative;
   this->Modified();
 
 } // end SetInitialDerivative()
@@ -84,7 +84,7 @@ MoreThuenteLineSearchOptimizer
 ::GetCurrentValueAndDerivative(
   MeasureType & value, DerivativeType & derivative ) const
 {
-  value = m_f;
+  value      = m_f;
   derivative = m_g;
 
 } // end GetCurrentValueAndDerivative()
@@ -96,7 +96,7 @@ MoreThuenteLineSearchOptimizer
 
 void
 MoreThuenteLineSearchOptimizer
-::GetCurrentDerivative( DerivativeType & derivative) const
+::GetCurrentDerivative( DerivativeType & derivative ) const
 {
   derivative = m_g;
 
@@ -147,24 +147,24 @@ MoreThuenteLineSearchOptimizer
 
   this->InvokeEvent( StartEvent() );
 
-  if (  this->m_dginit >= 0 )
+  if(  this->m_dginit >= 0 )
   {
     this->m_StopCondition = AscentSearchDirection;
     this->StopOptimization();
   }
 
-  while (! this->m_Stop)
+  while( !this->m_Stop )
   {
 
     this->UpdateIntervalMinimumAndMaximum();
-    this->BoundStep(this->m_step);
+    this->BoundStep( this->m_step );
     this->PrepareForUnusualTermination();
-    this->SetCurrentStepLength(this->m_step);
+    this->SetCurrentStepLength( this->m_step );
     this->ComputeCurrentValueAndDerivative();
     this->m_dg = this->DirectionalDerivative( this->m_g );
-    this->TestConvergence(this->m_Stop);
+    this->TestConvergence( this->m_Stop );
     this->InvokeEvent( IterationEvent() );
-    if ( this->m_Stop )
+    if( this->m_Stop )
     {
       this->StopOptimization();
       break;
@@ -200,7 +200,7 @@ int
 MoreThuenteLineSearchOptimizer
 ::CheckSettings( void )
 {
-  if ( this->GetCostFunction() == 0 )
+  if( this->GetCostFunction() == 0 )
   {
     itkExceptionMacro( << "CostFunction has not been set!" );
   }
@@ -208,27 +208,27 @@ MoreThuenteLineSearchOptimizer
   const unsigned int numberOfParameters
     = this->GetCostFunction()->GetNumberOfParameters();
 
-  if ( this->GetInitialPosition().GetSize() != numberOfParameters )
+  if( this->GetInitialPosition().GetSize() != numberOfParameters )
   {
     itkExceptionMacro( << "InitialPosition has incorrect dimension!" );
   }
 
-  if ( this->GetLineSearchDirection().GetSize() != numberOfParameters )
+  if( this->GetLineSearchDirection().GetSize() != numberOfParameters )
   {
     itkExceptionMacro( << "LineSearchDirection has incorrect dimension!" );
   }
 
-  if ( this->GetMinimumStepLength() <= 0.0 )
+  if( this->GetMinimumStepLength() <= 0.0 )
   {
     itkExceptionMacro( << "MinimumStepLength must be higher than zero!" );
   }
 
-  if ( this->GetMinimumStepLength() > this->GetMaximumStepLength() )
+  if( this->GetMinimumStepLength() > this->GetMaximumStepLength() )
   {
     itkExceptionMacro( << "MinimumStepLength must be smaller than MaximumStepLength!" );
   }
 
-  if ( this->GetGradientTolerance() < this->GetValueTolerance() )
+  if( this->GetGradientTolerance() < this->GetValueTolerance() )
   {
     itkExceptionMacro( << "GradientTolerance must be greater than ValueTolerance!" );
   }
@@ -246,24 +246,24 @@ MoreThuenteLineSearchOptimizer
 ::GetInitialValueAndDerivative( void )
 {
 
-  if ( !(this->m_InitialValueProvided && this->m_InitialDerivativeProvided) )
+  if( !( this->m_InitialValueProvided && this->m_InitialDerivativeProvided ) )
   {
 
     try
     {
-      if ( !this->m_InitialValueProvided && !this->m_InitialDerivativeProvided )
+      if( !this->m_InitialValueProvided && !this->m_InitialDerivativeProvided )
       {
         this->GetCostFunction()->GetValueAndDerivative(
           this->GetInitialPosition(),
           this->m_f,
           this->m_g );
       }
-      else if ( !this->m_InitialValueProvided )
+      else if( !this->m_InitialValueProvided )
       {
         this->m_f = this->GetCostFunction()->GetValue(
           this->GetInitialPosition() );
       }
-      else if ( !this->m_InitialDerivativeProvided )
+      else if( !this->m_InitialDerivativeProvided )
       {
         this->GetCostFunction()->GetDerivative(
           this->GetInitialPosition(),
@@ -271,7 +271,7 @@ MoreThuenteLineSearchOptimizer
       }
 
     }
-    catch ( ExceptionObject & err )
+    catch( ExceptionObject & err )
     {
       this->m_StopCondition = MetricError;
       //this->StopOptimization(); //not here since no start event has been generated yet
@@ -279,7 +279,7 @@ MoreThuenteLineSearchOptimizer
       /** Any user provided initial values/derivatives may not be
        * valid anymore */
       this->m_InitialDerivativeProvided = false;
-      this->m_InitialValueProvided = false;
+      this->m_InitialValueProvided      = false;
 
       throw err;
     }
@@ -289,7 +289,7 @@ MoreThuenteLineSearchOptimizer
    * valid anymore */
 
   this->m_InitialDerivativeProvided = false;
-  this->m_InitialValueProvided = false;
+  this->m_InitialValueProvided      = false;
 
 } // end GetInitialValueAndDerivative()
 
@@ -305,29 +305,29 @@ void
 MoreThuenteLineSearchOptimizer
 ::InitializeLineSearch( void )
 {
-  this->m_Stop = false;
-  this->m_StopCondition = Unknown;
-  this->m_CurrentIteration = 0;
+  this->m_Stop                                 = false;
+  this->m_StopCondition                        = Unknown;
+  this->m_CurrentIteration                     = 0;
   this->m_SufficientDecreaseConditionSatisfied = false;
-  this->m_CurvatureConditionSatisfied = false;
-  this->m_CurrentStepLength = 0.0;
+  this->m_CurvatureConditionSatisfied          = false;
+  this->m_CurrentStepLength                    = 0.0;
 
-  this->m_finit = this->m_f;
-  this->m_fx = this->m_finit;
-  this->m_fy = this->m_finit;
-  this->m_step = this->GetInitialStepLengthEstimate();
-  this->m_stepx = 0.0;
-  this->m_stepy = 0.0;
-  this->m_stepmin = 0.0;
-  this->m_stepmax = 0.0;
-  this->m_dginit = this->m_dg;
-  this->m_dgx = this->m_dginit;
-  this->m_dgy = this->m_dginit;
-  this->m_dgtest = this->GetValueTolerance() * this->m_dginit;
-  this->m_width = this->GetMaximumStepLength() - this->GetMinimumStepLength();
-  this->m_width1 = this->m_width / 0.5;
-  this->m_brackt = false;
-  this->m_stage1 = true;
+  this->m_finit                 = this->m_f;
+  this->m_fx                    = this->m_finit;
+  this->m_fy                    = this->m_finit;
+  this->m_step                  = this->GetInitialStepLengthEstimate();
+  this->m_stepx                 = 0.0;
+  this->m_stepy                 = 0.0;
+  this->m_stepmin               = 0.0;
+  this->m_stepmax               = 0.0;
+  this->m_dginit                = this->m_dg;
+  this->m_dgx                   = this->m_dginit;
+  this->m_dgy                   = this->m_dginit;
+  this->m_dgtest                = this->GetValueTolerance() * this->m_dginit;
+  this->m_width                 = this->GetMaximumStepLength() - this->GetMinimumStepLength();
+  this->m_width1                = this->m_width / 0.5;
+  this->m_brackt                = false;
+  this->m_stage1                = true;
   this->m_SafeGuardedStepFailed = false;
 
 } // end InitializeLineSearch()
@@ -346,7 +346,7 @@ MoreThuenteLineSearchOptimizer
 {
   const double xtrapf = 4.0;
 
-  if ( this->m_brackt )
+  if( this->m_brackt )
   {
     this->m_stepmin = vnl_math_min( this->m_stepx, this->m_stepy );
     this->m_stepmax = vnl_math_max( this->m_stepx, this->m_stepy );
@@ -354,8 +354,8 @@ MoreThuenteLineSearchOptimizer
   else
   {
     this->m_stepmin = this->m_stepx;
-    this->m_stepmax =
-      this->m_step + xtrapf * ( this->m_step - this->m_stepx );
+    this->m_stepmax
+      = this->m_step + xtrapf * ( this->m_step - this->m_stepx );
   }
 
 } // end UpdateIntervalMinimumAndMaximum()
@@ -389,9 +389,9 @@ void
 MoreThuenteLineSearchOptimizer
 ::PrepareForUnusualTermination( void )
 {
-  if ( ( this->m_brackt
+  if( ( this->m_brackt
     && ( this->m_step <= this->m_stepmin
-    || this->m_step >= this->m_stepmax))
+    || this->m_step >= this->m_stepmax ) )
     || this->m_CurrentIteration >= this->GetMaximumNumberOfIterations() - 1
     || this->m_SafeGuardedStepFailed
     || ( this->m_brackt
@@ -419,7 +419,7 @@ MoreThuenteLineSearchOptimizer
     this->GetCostFunction()->GetValueAndDerivative(
       this->GetCurrentPosition(), this->m_f, this->m_g );
   }
-  catch ( ExceptionObject & err )
+  catch( ExceptionObject & err )
   {
     this->m_StopCondition = MetricError;
     this->StopOptimization();
@@ -445,52 +445,52 @@ MoreThuenteLineSearchOptimizer
   MeasureType ftest1 = this->m_finit + step * this->m_dgtest;
 
   this->m_SufficientDecreaseConditionSatisfied = ( this->m_f <= ftest1 );
-  this->m_CurvatureConditionSatisfied = ( vnl_math_abs(this->m_dg) <=
-    this->GetGradientTolerance() * ( - this->m_dginit ) );
+  this->m_CurvatureConditionSatisfied          = ( vnl_math_abs( this->m_dg ) <=
+    this->GetGradientTolerance() * ( -this->m_dginit ) );
 
-  if ( (this->m_brackt
-    && (step <= this->m_stepmin || step >= this->m_stepmax))
+  if( ( this->m_brackt
+    && ( step <= this->m_stepmin || step >= this->m_stepmax ) )
     || this->m_SafeGuardedStepFailed )
   {
     this->m_StopCondition = RoundingError;
-    stop = true;
+    stop                  = true;
   }
 
-  if ( step == this->GetMaximumStepLength()
+  if( step == this->GetMaximumStepLength()
     && this->m_SufficientDecreaseConditionSatisfied
     && this->m_dg <= this->m_dgtest )
   {
     this->m_StopCondition = StepTooLarge;
-    stop = true;
+    stop                  = true;
   }
 
-  if ( step == this->GetMinimumStepLength()
-    && ( !(this->m_SufficientDecreaseConditionSatisfied)
-    || this->m_dg >= this->m_dgtest) )
+  if( step == this->GetMinimumStepLength()
+    && ( !( this->m_SufficientDecreaseConditionSatisfied )
+    || this->m_dg >= this->m_dgtest ) )
   {
     this->m_StopCondition = StepTooSmall;
-    stop = true;
+    stop                  = true;
   }
 
-  if ( this->m_CurrentIteration >= this->GetMaximumNumberOfIterations() - 1 )
+  if( this->m_CurrentIteration >= this->GetMaximumNumberOfIterations() - 1 )
   {
     this->m_StopCondition = MaximumNumberOfIterations;
-    stop = true;
+    stop                  = true;
   }
 
-  if ( this->m_brackt
+  if( this->m_brackt
     && this->m_stepmax - this->m_stepmin
     <= this->GetIntervalTolerance() * this->m_stepmax )
   {
     this->m_StopCondition = IntervalTooSmall;
-    stop = true;
+    stop                  = true;
   }
 
-  if ( this->m_SufficientDecreaseConditionSatisfied
+  if( this->m_SufficientDecreaseConditionSatisfied
     && this->m_CurvatureConditionSatisfied  )
   {
     this->m_StopCondition = StrongWolfeConditionsSatisfied;
-    stop = true;
+    stop                  = true;
   }
 
 } // end TestConvergence()
@@ -512,10 +512,10 @@ MoreThuenteLineSearchOptimizer
   * function has a nonpositive value and nonnegative derivative. */
 
   /** Stage1? */
-  if ( this->m_stage1
+  if( this->m_stage1
     && this->m_SufficientDecreaseConditionSatisfied
     && this->m_dg >= this->m_dginit * vnl_math_min(
-    this->GetValueTolerance(), this->GetGradientTolerance())   )
+    this->GetValueTolerance(), this->GetGradientTolerance() ) )
   {
     this->m_stage1 = false;
   }
@@ -526,17 +526,17 @@ MoreThuenteLineSearchOptimizer
   * derivative, and if a lower function value has been
   * obtained but the decrease is not sufficient. */
 
-  if ( this->m_stage1
+  if( this->m_stage1
     && this->m_f <= this->m_fx
-    && !(this->m_SufficientDecreaseConditionSatisfied)   )
+    && !( this->m_SufficientDecreaseConditionSatisfied ) )
   {
     /* Define the modified function and derivative values. */
     const double & dgtest = this->m_dgtest;
 
-    double fm = this->m_f - this->m_step * dgtest;
-    double fxm = this->m_fx - this->m_stepx * dgtest;
-    double fym = this->m_fy - this->m_stepy * dgtest;
-    double dgm = this->m_dg - dgtest;
+    double fm   = this->m_f - this->m_step * dgtest;
+    double fxm  = this->m_fx - this->m_stepx * dgtest;
+    double fym  = this->m_fy - this->m_stepy * dgtest;
+    double dgm  = this->m_dg - dgtest;
     double dgxm = this->m_dgx - dgtest;
     double dgym = this->m_dgy - dgtest;
 
@@ -547,11 +547,11 @@ MoreThuenteLineSearchOptimizer
       this->m_stepy, fym, dgym,
       this->m_step, fm, dgm,
       this->m_brackt,
-      this->m_stepmin, this->m_stepmax);
+      this->m_stepmin, this->m_stepmax );
 
     /* Reset the function and gradient values. */
-    this->m_fx = fxm + this->m_stepx * dgtest;
-    this->m_fy = fym + this->m_stepy * dgtest;
+    this->m_fx  = fxm + this->m_stepx * dgtest;
+    this->m_fy  = fym + this->m_stepy * dgtest;
     this->m_dgx = dgxm + dgtest;
     this->m_dgy = dgym + dgtest;
   }
@@ -564,10 +564,10 @@ MoreThuenteLineSearchOptimizer
       this->m_stepy, this->m_fy, this->m_dgy,
       this->m_step, this->m_f, this->m_dg,
       this->m_brackt,
-      this->m_stepmin, this->m_stepmax);
+      this->m_stepmin, this->m_stepmax );
   }
 
-  if (returncode == 0)
+  if( returncode == 0 )
   {
     this->m_SafeGuardedStepFailed = true;
   }
@@ -585,17 +585,17 @@ void
 MoreThuenteLineSearchOptimizer
 ::ForceSufficientDecreaseInIntervalWidth( void )
 {
-  if ( this->m_brackt )
+  if( this->m_brackt )
   {
     const double & stx = this->m_stepx;
     const double & sty = this->m_stepy;
 
-    if ( vnl_math_abs(sty - stx) >= .66 * this->m_width1 )
+    if( vnl_math_abs( sty - stx ) >= .66 * this->m_width1 )
     {
-      this->m_step = stx + .5 * (sty - stx);
+      this->m_step = stx + .5 * ( sty - stx );
     }
     this->m_width1 = this->m_width;
-    this->m_width = vnl_math_abs(sty - stx);
+    this->m_width  = vnl_math_abs( sty - stx );
   }
 
 } // end ForceSufficientDecreaseInIntervalWidth()
@@ -686,7 +686,6 @@ MoreThuenteLineSearchOptimizer
   /*     ARGONNE NATIONAL LABORATORY. MINPACK PROJECT. JUNE 1983 */
   /*     JORGE J. MORE', DAVID J. THUENTE */
 
-
   /** The info variable is now replaced by the returncode. */
   /** The variables are no longer passed as pointers, but by reference. */
 
@@ -695,56 +694,56 @@ MoreThuenteLineSearchOptimizer
 
   /* Local variables */
   double sgnd, stpc, stpf, stpq, p, q, gamma, r, s, theta;
-  bool bound;
+  bool   bound;
 
   int returncode = 0;
 
   /* CHECK THE INPUT PARAMETERS FOR ERRORS. */
 
-  if ( (brackt && ( stp <= vnl_math_min(stx,sty)
-    || stp >= vnl_math_max(stx,sty) ))
-    || dx * (stp - stx) >= 0.
-    || stpmax < stpmin   )
+  if( ( brackt && ( stp <= vnl_math_min( stx, sty )
+    || stp >= vnl_math_max( stx, sty ) ) )
+    || dx * ( stp - stx ) >= 0.
+    || stpmax < stpmin )
   {
     return returncode;
   }
 
   /* DETERMINE IF THE DERIVATIVES HAVE OPPOSITE SIGN. */
 
-  sgnd = dp * ( dx / vnl_math_abs(dx) );
+  sgnd = dp * ( dx / vnl_math_abs( dx ) );
 
   /*     FIRST CASE. A HIGHER FUNCTION VALUE. */
   /*     THE MINIMUM IS BRACKETED. IF THE CUBIC STEP IS CLOSER */
   /*     TO STX THAN THE QUADRATIC STEP, THE CUBIC STEP IS TAKEN, */
   /*     ELSE THE AVERAGE OF THE CUBIC AND QUADRATIC STEPS IS TAKEN. */
 
-  if (fp > fx)
+  if( fp > fx )
   {
     returncode = 1;
-    bound = true;
-    theta = (fx - fp) * 3 / (stp - stx) + dx + dp;
-    s = vnl_math_max(
-      vnl_math_max( vnl_math_abs(theta), vnl_math_abs(dx) ),
-      vnl_math_abs(dp) );
-    d__1 = theta / s;
-    gamma = s * vcl_sqrt( d__1 * d__1 - dx/s * (dp/s) );
-    if (stp < stx)
+    bound      = true;
+    theta      = ( fx - fp ) * 3 / ( stp - stx ) + dx + dp;
+    s          = vnl_math_max(
+      vnl_math_max( vnl_math_abs( theta ), vnl_math_abs( dx ) ),
+      vnl_math_abs( dp ) );
+    d__1  = theta / s;
+    gamma = s * vcl_sqrt( d__1 * d__1 - dx / s * ( dp / s ) );
+    if( stp < stx )
     {
       gamma = -gamma;
     }
-    p = gamma - dx + theta;
-    q = gamma - dx + gamma + dp;
-    r = p / q;
-    stpc = stx + r * (stp - stx);
-    stpq = stx +
-      dx / ((fx - fp) / (stp - stx) + dx) / 2 * (stp - stx);
-    if ( vnl_math_abs(stpc - stx) < vnl_math_abs(stpq - stx) )
+    p    = gamma - dx + theta;
+    q    = gamma - dx + gamma + dp;
+    r    = p / q;
+    stpc = stx + r * ( stp - stx );
+    stpq = stx
+      + dx / ( ( fx - fp ) / ( stp - stx ) + dx ) / 2 * ( stp - stx );
+    if( vnl_math_abs( stpc - stx ) < vnl_math_abs( stpq - stx ) )
     {
       stpf = stpc;
     }
     else
     {
-      stpf = stpc + (stpq - stpc) / 2;
+      stpf = stpc + ( stpq - stpc ) / 2;
     }
     brackt = true;
 
@@ -754,26 +753,26 @@ MoreThuenteLineSearchOptimizer
     /*     THE CUBIC STEP IS TAKEN, ELSE THE QUADRATIC STEP IS TAKEN. */
 
   }
-  else if (sgnd < 0.)
+  else if( sgnd < 0. )
   {
     returncode = 2;
-    bound = false;
-    theta = (fx - fp) * 3 / (stp - stx) + dx + dp;
-    s = vnl_math_max(
-      vnl_math_max( vnl_math_abs(theta), vnl_math_abs(dx) ),
-      vnl_math_abs(dp)  );
-    d__1 = theta / s;
-    gamma = s * vcl_sqrt(d__1 * d__1 - dx / s * (dp/s));
-    if (stp > stx)
+    bound      = false;
+    theta      = ( fx - fp ) * 3 / ( stp - stx ) + dx + dp;
+    s          = vnl_math_max(
+      vnl_math_max( vnl_math_abs( theta ), vnl_math_abs( dx ) ),
+      vnl_math_abs( dp ) );
+    d__1  = theta / s;
+    gamma = s * vcl_sqrt( d__1 * d__1 - dx / s * ( dp / s ) );
+    if( stp > stx )
     {
       gamma = -gamma;
     }
-    p = gamma - dp + theta;
-    q = gamma - dp + gamma + dx;
-    r = p / q;
-    stpc = stp + r * (stx - stp);
-    stpq = stp + dp / (dp - dx) * (stx - stp);
-    if (vnl_math_abs(stpc - stp) > vnl_math_abs(stpq - stp))
+    p    = gamma - dp + theta;
+    q    = gamma - dp + gamma + dx;
+    r    = p / q;
+    stpc = stp + r * ( stx - stp );
+    stpq = stp + dp / ( dp - dx ) * ( stx - stp );
+    if( vnl_math_abs( stpc - stp ) > vnl_math_abs( stpq - stp ) )
     {
       stpf = stpc;
     }
@@ -793,33 +792,33 @@ MoreThuenteLineSearchOptimizer
     /*     CLOSEST TO STX IS TAKEN, ELSE THE STEP FARTHEST AWAY IS TAKEN. */
 
   }
-  else if (vnl_math_abs(dp) < vnl_math_abs(dx))
+  else if( vnl_math_abs( dp ) < vnl_math_abs( dx ) )
   {
     returncode = 3;
-    bound = true;
-    theta = (fx - fp) * 3 / (stp - stx) + dx + dp;
-    s = vnl_math_max(
-      vnl_math_max( vnl_math_abs(theta), vnl_math_abs(dx) ),
-      vnl_math_abs(dp)   );
+    bound      = true;
+    theta      = ( fx - fp ) * 3 / ( stp - stx ) + dx + dp;
+    s          = vnl_math_max(
+      vnl_math_max( vnl_math_abs( theta ), vnl_math_abs( dx ) ),
+      vnl_math_abs( dp ) );
 
     /* THE CASE GAMMA = 0 ONLY ARISES IF THE CUBIC DOES NOT TEND */
     /* TO INFINITY IN THE DIRECTION OF THE STEP. */
 
-    d__1 = theta / s;
-    d__1 = d__1 * d__1 - dx / s * (dp / s);
-    gamma = s * vcl_sqrt( vnl_math_max(0.,d__1) );
-    if (stp > stx)
+    d__1  = theta / s;
+    d__1  = d__1 * d__1 - dx / s * ( dp / s );
+    gamma = s * vcl_sqrt( vnl_math_max( 0., d__1 ) );
+    if( stp > stx )
     {
       gamma = -gamma;
     }
     p = gamma - dp + theta;
-    q = gamma + (dx - dp) + gamma;
+    q = gamma + ( dx - dp ) + gamma;
     r = p / q;
-    if (r < 0. && gamma != 0.)
+    if( r < 0. && gamma != 0. )
     {
-      stpc = stp + r * (stx - stp);
+      stpc = stp + r * ( stx - stp );
     }
-    else if (stp > stx)
+    else if( stp > stx )
     {
       stpc = stpmax;
     }
@@ -827,10 +826,10 @@ MoreThuenteLineSearchOptimizer
     {
       stpc = stpmin;
     }
-    stpq = stp + dp / (dp - dx) * (stx - stp);
-    if (brackt)
+    stpq = stp + dp / ( dp - dx ) * ( stx - stp );
+    if( brackt )
     {
-      if (vnl_math_abs(stp - stpc) < vnl_math_abs(stp - stpq))
+      if( vnl_math_abs( stp - stpc ) < vnl_math_abs( stp - stpq ) )
       {
         stpf = stpc;
       }
@@ -841,7 +840,7 @@ MoreThuenteLineSearchOptimizer
     }
     else
     {
-      if (vnl_math_abs(stp - stpc) > vnl_math_abs(stp - stpq))
+      if( vnl_math_abs( stp - stpc ) > vnl_math_abs( stp - stpq ) )
       {
         stpf = stpc;
       }
@@ -860,26 +859,26 @@ MoreThuenteLineSearchOptimizer
   else
   {
     returncode = 4;
-    bound = false;
-    if (brackt)
+    bound      = false;
+    if( brackt )
     {
-      theta = (fp - fy) * 3 / (sty - stp) + dy + dp;
-      s = vnl_math_max(
-        vnl_math_max( vnl_math_abs(theta),vnl_math_abs(dy) ),
-        vnl_math_abs(dp)  );
-      d__1 = theta / s;
-      gamma = s * vcl_sqrt(d__1 * d__1 - dy / s * (dp/s) );
-      if (stp > sty)
+      theta = ( fp - fy ) * 3 / ( sty - stp ) + dy + dp;
+      s     = vnl_math_max(
+        vnl_math_max( vnl_math_abs( theta ), vnl_math_abs( dy ) ),
+        vnl_math_abs( dp ) );
+      d__1  = theta / s;
+      gamma = s * vcl_sqrt( d__1 * d__1 - dy / s * ( dp / s ) );
+      if( stp > sty )
       {
         gamma = -gamma;
       }
-      p = gamma - dp + theta;
-      q = gamma - dp + gamma + dy;
-      r = p / q;
-      stpc = stp + r * (sty - stp);
+      p    = gamma - dp + theta;
+      q    = gamma - dp + gamma + dy;
+      r    = p / q;
+      stpc = stp + r * ( sty - stp );
       stpf = stpc;
     }
-    else if (stp > stx)
+    else if( stp > stx )
     {
       stpf = stpmax;
     }
@@ -892,41 +891,41 @@ MoreThuenteLineSearchOptimizer
   /*     UPDATE THE INTERVAL OF UNCERTAINTY. THIS UPDATE DOES NOT */
   /*     DEPEND ON THE NEW STEP OR THE CASE ANALYSIS ABOVE. */
 
-  if (fp > fx)
+  if( fp > fx )
   {
     sty = stp;
-    fy = fp;
-    dy = dp;
+    fy  = fp;
+    dy  = dp;
   }
   else
   {
-    if (sgnd < 0.)
+    if( sgnd < 0. )
     {
       sty = stx;
-      fy = fx;
-      dy = dx;
+      fy  = fx;
+      dy  = dx;
     }
     stx = stp;
-    fx = fp;
-    dx = dp;
+    fx  = fp;
+    dx  = dp;
   }
 
   /*     COMPUTE THE NEW STEP AND SAFEGUARD IT. */
 
-  stpf = vnl_math_min(stpmax, stpf);
-  stpf = vnl_math_max(stpmin, stpf);
-  stp = stpf;
-  if (brackt && bound)
+  stpf = vnl_math_min( stpmax, stpf );
+  stpf = vnl_math_max( stpmin, stpf );
+  stp  = stpf;
+  if( brackt && bound )
   {
-    if (sty > stx)
+    if( sty > stx )
     {
-      d__1 = stx + (sty - stx) * .66f;
-      stp = vnl_math_min(d__1,stp);
+      d__1 = stx + ( sty - stx ) * .66f;
+      stp  = vnl_math_min( d__1, stp );
     }
     else
     {
-      d__1 = stx + (sty - stx) * .66f;
-      stp = vnl_math_max(d__1,stp);
+      d__1 = stx + ( sty - stx ) * .66f;
+      stp  = vnl_math_max( d__1, stp );
     }
   }
 
@@ -941,78 +940,78 @@ MoreThuenteLineSearchOptimizer
 
 void
 MoreThuenteLineSearchOptimizer
-::PrintSelf( std::ostream& os, Indent indent ) const
+::PrintSelf( std::ostream & os, Indent indent ) const
 {
   /** Call the superclass' PrintSelf. */
   Superclass::PrintSelf( os, indent );
 
   os << indent << "m_CurrentIteration: "
-    << this->m_CurrentIteration << std::endl;
+     << this->m_CurrentIteration << std::endl;
   os << indent << "m_InitialDerivativeProvided: "
-    << ( this->m_InitialDerivativeProvided ? "true" : "false" ) << std::endl;
+     << ( this->m_InitialDerivativeProvided ? "true" : "false" ) << std::endl;
   os << indent << "m_InitialValueProvided: "
-    << ( this->m_InitialValueProvided ? "true" : "false" ) << std::endl;
+     << ( this->m_InitialValueProvided ? "true" : "false" ) << std::endl;
   os << indent << "m_StopCondition: "
-    << this->m_StopCondition << std::endl;
+     << this->m_StopCondition << std::endl;
   os << indent << "m_Stop: "
-    << ( this->m_Stop ? "true" : "false" ) << std::endl;
+     << ( this->m_Stop ? "true" : "false" ) << std::endl;
   os << indent << "m_SufficientDecreaseConditionSatisfied: "
-    << ( this->m_SufficientDecreaseConditionSatisfied ? "true" : "false" ) << std::endl;
+     << ( this->m_SufficientDecreaseConditionSatisfied ? "true" : "false" ) << std::endl;
   os << indent << "m_CurvatureConditionSatisfied: "
-    << ( this->m_CurvatureConditionSatisfied ? "true" : "false" ) << std::endl;
+     << ( this->m_CurvatureConditionSatisfied ? "true" : "false" ) << std::endl;
 
   os << indent << "m_step: "
-    << this->m_step << std::endl;
+     << this->m_step << std::endl;
   os << indent << "m_stepx: "
-    << this->m_stepx << std::endl;
+     << this->m_stepx << std::endl;
   os << indent << "m_stepy: "
-    << this->m_stepy << std::endl;
+     << this->m_stepy << std::endl;
   os << indent << "m_stepmin: "
-    << this->m_stepmin << std::endl;
+     << this->m_stepmin << std::endl;
   os << indent << "m_stepmax: "
-    << this->m_stepmax << std::endl;
+     << this->m_stepmax << std::endl;
 
   os << indent << "m_f: "
-    << this->m_f << std::endl;
+     << this->m_f << std::endl;
   os << indent << "m_fx: "
-    << this->m_fx << std::endl;
+     << this->m_fx << std::endl;
   os << indent << "m_fy: "
-    << this->m_fy << std::endl;
+     << this->m_fy << std::endl;
   os << indent << "m_finit: "
-    << this->m_finit << std::endl;
+     << this->m_finit << std::endl;
 
   os << indent << "m_g: "
-    << this->m_g << std::endl;
+     << this->m_g << std::endl;
   os << indent << "m_dg: "
-    << this->m_dg << std::endl;
+     << this->m_dg << std::endl;
   os << indent << "m_dginit: "
-    << this->m_dginit << std::endl;
+     << this->m_dginit << std::endl;
   os << indent << "m_dgx: "
-    << this->m_dgx << std::endl;
+     << this->m_dgx << std::endl;
   os << indent << "m_dgy: "
-    << this->m_dgy << std::endl;
+     << this->m_dgy << std::endl;
   os << indent << "m_dgtest: "
-    << this->m_dgtest << std::endl;
+     << this->m_dgtest << std::endl;
 
   os << indent << "m_width: "
-    << this->m_width << std::endl;
+     << this->m_width << std::endl;
   os << indent << "m_width1: "
-    << this->m_width1 << std::endl;
+     << this->m_width1 << std::endl;
   os << indent << "m_brackt: "
-    << ( this->m_brackt ? "true" : "false" ) << std::endl;
+     << ( this->m_brackt ? "true" : "false" ) << std::endl;
   os << indent << "m_stage1: "
-    << ( this->m_stage1 ? "true" : "false" ) << std::endl;
+     << ( this->m_stage1 ? "true" : "false" ) << std::endl;
   os << indent << "m_SafeGuardedStepFailed: "
-    << ( this->m_SafeGuardedStepFailed ? "true" : "false" ) << std::endl;
+     << ( this->m_SafeGuardedStepFailed ? "true" : "false" ) << std::endl;
 
   os << indent << "m_MaximumNumberOfIterations: "
-    << this->m_MaximumNumberOfIterations << std::endl;
+     << this->m_MaximumNumberOfIterations << std::endl;
   os << indent << "m_ValueTolerance: "
-    << this->m_ValueTolerance << std::endl;
+     << this->m_ValueTolerance << std::endl;
   os << indent << "m_GradientTolerance: "
-    << this->m_GradientTolerance << std::endl;
+     << this->m_GradientTolerance << std::endl;
   os << indent << "m_IntervalTolerance: "
-    << this->m_IntervalTolerance << std::endl;
+     << this->m_IntervalTolerance << std::endl;
 
 } // end PrintSelf()
 
@@ -1020,4 +1019,3 @@ MoreThuenteLineSearchOptimizer
 } // end namespace itk
 
 #endif // #ifndef __itkMoreThuenteLineSearchOptimizer_cxx
-
