@@ -9,8 +9,8 @@
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
@@ -19,32 +19,38 @@
 #include "itkMevisDicomTiffImageIO.h"
 #include "itkVersion.h"
 
-  
 namespace itk
 {
-MevisDicomTiffImageIOFactory::MevisDicomTiffImageIOFactory()
-{
-  this->RegisterOverride("itkImageIOBase",
-                         "itkMevisDicomTiffImageIO",
-                         "Mevis Dicom/TIFF Image IO",
-                         1,
-                         CreateObjectFunction<MevisDicomTiffImageIO>::New());
-}
-  
-MevisDicomTiffImageIOFactory::~MevisDicomTiffImageIOFactory()
+
+MevisDicomTiffImageIOFactory
+::MevisDicomTiffImageIOFactory()
 {
+  this->RegisterOverride( "itkImageIOBase",
+    "itkMevisDicomTiffImageIO",
+    "Mevis Dicom/TIFF Image IO",
+    1,
+    CreateObjectFunction< MevisDicomTiffImageIO >::New() );
 }
 
-const char* 
-MevisDicomTiffImageIOFactory::GetITKSourceVersion() const
+
+MevisDicomTiffImageIOFactory
+::~MevisDicomTiffImageIOFactory()
+{}
+
+const char *
+MevisDicomTiffImageIOFactory
+::GetITKSourceVersion( void ) const
 {
   return ITK_SOURCE_VERSION;
 }
 
-const char* 
-MevisDicomTiffImageIOFactory::GetDescription() const
+
+const char *
+MevisDicomTiffImageIOFactory
+::GetDescription( void ) const
 {
   return "Mevis Dicom/TIFF ImageIO Factory, allows the loading of Mevis images into insight";
 }
 
+
 } // end namespace itk
