@@ -11,7 +11,6 @@ the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE. See the above copyright notices for more information.
 
 ======================================================================*/
-
 #ifndef __itkAdvancedBSplineDeformableTransformBase_h
 #define __itkAdvancedBSplineDeformableTransformBase_h
 
@@ -19,7 +18,6 @@ PURPOSE. See the above copyright notices for more information.
 #include "itkImage.h"
 #include "itkImageRegion.h"
 
-
 namespace itk
 {
 
@@ -33,19 +31,21 @@ namespace itk
  * different spline orders more convenient in subsequent code.
  *
  */
-template <
-    class TScalarType = double,          // Data type for scalars
-    unsigned int NDimensions = 3 >       // Number of dimensions
-class ITK_EXPORT AdvancedBSplineDeformableTransformBase
-  : public AdvancedTransform< TScalarType, NDimensions, NDimensions >
+template<
+class TScalarType        = double,       // Data type for scalars
+unsigned int NDimensions = 3 >
+// Number of dimensions
+class AdvancedBSplineDeformableTransformBase :
+  public AdvancedTransform< TScalarType, NDimensions, NDimensions >
 {
 public:
+
   /** Standard class typedefs. */
-  typedef AdvancedBSplineDeformableTransformBase    Self;
+  typedef AdvancedBSplineDeformableTransformBase Self;
   typedef AdvancedTransform<
     TScalarType, NDimensions, NDimensions >         Superclass;
-  typedef SmartPointer<Self>                        Pointer;
-  typedef SmartPointer<const Self>                  ConstPointer;
+  typedef SmartPointer< Self >       Pointer;
+  typedef SmartPointer< const Self > ConstPointer;
 
   /** Run-time type information (and related methods). */
   itkTypeMacro( AdvancedBSplineDeformableTransformBase, AdvancedTransform );
@@ -55,6 +55,7 @@ public:
 
   /** Typedefs from Superclass. */
   typedef typename Superclass::ParametersType         ParametersType;
+  typedef typename Superclass::NumberOfParametersType NumberOfParametersType;
   typedef typename Superclass::JacobianType           JacobianType;
   typedef typename Superclass::ScalarType             ScalarType;
   typedef typename Superclass::InputPointType         InputPointType;
@@ -67,16 +68,17 @@ public:
     InputCovariantVectorType;
   typedef typename Superclass::OutputCovariantVectorType
     OutputCovariantVectorType;
+  typedef typename Superclass::TransformCategoryType TransformCategoryType;
 
   typedef typename Superclass
-    ::NonZeroJacobianIndicesType                    NonZeroJacobianIndicesType;
-  typedef typename Superclass::SpatialJacobianType  SpatialJacobianType;
+    ::NonZeroJacobianIndicesType NonZeroJacobianIndicesType;
+  typedef typename Superclass::SpatialJacobianType SpatialJacobianType;
   typedef typename Superclass
-    ::JacobianOfSpatialJacobianType                 JacobianOfSpatialJacobianType;
-  typedef typename Superclass::SpatialHessianType   SpatialHessianType;
+    ::JacobianOfSpatialJacobianType JacobianOfSpatialJacobianType;
+  typedef typename Superclass::SpatialHessianType SpatialHessianType;
   typedef typename Superclass
-    ::JacobianOfSpatialHessianType                  JacobianOfSpatialHessianType;
-  typedef typename Superclass::InternalMatrixType   InternalMatrixType;
+    ::JacobianOfSpatialHessianType JacobianOfSpatialHessianType;
+  typedef typename Superclass::InternalMatrixType InternalMatrixType;
 
   /** This method sets the parameters of the transform.
      * For a B-spline deformation transform, the parameters are the BSpline
@@ -144,20 +146,20 @@ public:
   void SetIdentity( void );
 
   /** Get the Transformation Parameters. */
-  virtual const ParametersType& GetParameters( void ) const;
+  virtual const ParametersType & GetParameters( void ) const;
 
   /** Get the Transformation Fixed Parameters. */
-  virtual const ParametersType& GetFixedParameters( void ) const;
+  virtual const ParametersType & GetFixedParameters( void ) const;
 
   /** Parameters as SpaceDimension number of images. */
-  typedef typename ParametersType::ValueType            PixelType;
+  typedef typename ParametersType::ValueType PixelType;
   typedef Image< PixelType,
-    itkGetStaticConstMacro( SpaceDimension )>           ImageType;
-  typedef typename ImageType::Pointer                   ImagePointer;
+    itkGetStaticConstMacro( SpaceDimension ) >           ImageType;
+  typedef typename ImageType::Pointer ImagePointer;
 
   /** Get the array of coefficient images. */
-  virtual const ImagePointer * GetCoefficientImage( void ) const
-    { return this->m_CoefficientImage; }
+  virtual const ImagePointer * GetCoefficientImages( void ) const
+  { return this->m_CoefficientImages; }
 
   /** Set the array of coefficient images.
    *
@@ -167,10 +169,10 @@ public:
    * the buffered region of all the subsequent images are the same
    * as the first image. Note that no error checking is done.
    *
-   * Warning: use either the SetParameters() or SetCoefficientImage()
+   * Warning: use either the SetParameters() or SetCoefficientImages()
    * API. Mixing the two modes may results in unexpected results.
    */
-  virtual void SetCoefficientImage( ImagePointer images[] );
+  virtual void SetCoefficientImages( ImagePointer images[] );
 
   /** Typedefs for specifying the extend to the grid. */
   typedef ImageRegion< itkGetStaticConstMacro( SpaceDimension ) > RegionType;
@@ -183,61 +185,68 @@ public:
   typedef IndexType                         GridOffsetType;
 
   /** This method specifies the region over which the grid resides. */
-  virtual void SetGridRegion( const RegionType& region ) = 0;
+  virtual void SetGridRegion( const RegionType & region ) = 0;
+
   //itkGetMacro( GridRegion, RegionType );
   itkGetConstMacro( GridRegion, RegionType );
 
   /** This method specifies the grid spacing or resolution. */
   virtual void SetGridSpacing( const SpacingType & spacing );
+
   //itkGetMacro( GridSpacing, SpacingType );
   itkGetConstMacro( GridSpacing, SpacingType );
 
   /** This method specifies the grid directions . */
   virtual void SetGridDirection( const DirectionType & direction );
+
   //itkGetMacro( GridDirection, DirectionType );
   itkGetConstMacro( GridDirection, DirectionType );
 
   /** This method specifies the grid origin. */
-  virtual void SetGridOrigin( const OriginType& origin );
+  virtual void SetGridOrigin( const OriginType & origin );
+
   //itkGetMacro( GridOrigin, OriginType );
   itkGetConstMacro( GridOrigin, OriginType );
 
   /** Parameter index array type. */
-  typedef Array<unsigned long> ParameterIndexArrayType;
+  typedef Array< unsigned long > ParameterIndexArrayType;
 
   /** Method to transform a vector -
    *  not applicable for this type of transform.
    */
   virtual OutputVectorType TransformVector( const InputVectorType & ) const
-    {
+  {
     itkExceptionMacro( << "Method not applicable for deformable transform." );
     return OutputVectorType();
-    }
+  }
+
 
   /** Method to transform a vnl_vector -
    *  not applicable for this type of transform.
    */
   virtual OutputVnlVectorType TransformVector( const InputVnlVectorType & ) const
-    {
-    itkExceptionMacro( << "Method not applicable for deformable transform. ");
+  {
+    itkExceptionMacro( << "Method not applicable for deformable transform. " );
     return OutputVnlVectorType();
-    }
+  }
+
 
   /** Method to transform a CovariantVector -
    *  not applicable for this type of transform.
    */
   virtual OutputCovariantVectorType TransformCovariantVector(
     const InputCovariantVectorType & ) const
-    {
-    itkExceptionMacro( << "Method not applicable for deformable transform. ");
+  {
+    itkExceptionMacro( << "Method not applicable for deformable transform. " );
     return OutputCovariantVectorType();
-    }
+  }
+
 
   /** Return the number of parameters that completely define the Transform. */
-  virtual unsigned int GetNumberOfParameters( void ) const;
+  virtual NumberOfParametersType GetNumberOfParameters( void ) const;
 
   /** Return the number of parameters per dimension */
-  virtual unsigned int GetNumberOfParametersPerDimension( void ) const;
+  virtual NumberOfParametersType GetNumberOfParametersPerDimension( void ) const;
 
   /** Return the region of the grid wholly within the support region */
   itkGetConstReferenceMacro( ValidRegion, RegionType );
@@ -249,18 +258,28 @@ public:
    */
   virtual bool IsLinear( void ) const { return false; }
 
+  /** Indicates the category transform.
+   *  e.g. an affine transform, or a local one, e.g. a deformation field.
+   */
+  virtual TransformCategoryType GetTransformCategory( void ) const
+  {
+    return Self::BSpline;
+  }
+
+
   virtual unsigned int GetNumberOfAffectedWeights( void ) const = 0;
 
-  virtual unsigned long GetNumberOfNonZeroJacobianIndices( void ) const = 0;
+  virtual NumberOfParametersType GetNumberOfNonZeroJacobianIndices( void ) const = 0;
 
   /** This typedef should be equal to the typedef used
    * in derived classes based on the weights function.
    */
-  typedef ContinuousIndex<ScalarType, SpaceDimension> ContinuousIndexType;
+  typedef ContinuousIndex< ScalarType, SpaceDimension > ContinuousIndexType;
 
 protected:
+
   /** Print contents of an AdvancedBSplineDeformableTransformBase. */
-  virtual void PrintSelf( std::ostream &os, Indent indent ) const;
+  virtual void PrintSelf( std::ostream & os, Indent indent ) const;
 
   AdvancedBSplineDeformableTransformBase();
   virtual ~AdvancedBSplineDeformableTransformBase();
@@ -270,34 +289,39 @@ protected:
 
   /** Convert an input point to a continuous index inside the B-spline grid. */
   void TransformPointToContinuousGridIndex(
-   const InputPointType & point, ContinuousIndexType & index ) const;
+    const InputPointType & point, ContinuousIndexType & index ) const;
+
+  void UpdatePointIndexConversions( void );
 
   virtual void ComputeNonZeroJacobianIndices(
     NonZeroJacobianIndicesType & nonZeroJacobianIndices,
     const RegionType & supportRegion ) const = 0;
 
   /** Check if a continuous index is inside the valid region. */
-  virtual bool InsideValidRegion( const ContinuousIndexType& index ) const;
+  virtual bool InsideValidRegion( const ContinuousIndexType & index ) const;
 
   /** Array of images representing the B-spline coefficients
    *  in each dimension.
    */
-  ImagePointer        m_CoefficientImage[ NDimensions ];
+  ImagePointer m_CoefficientImages[ NDimensions ];
 
   /** Variables defining the coefficient grid extend. */
-  RegionType          m_GridRegion;
-  SpacingType         m_GridSpacing;
-  DirectionType       m_GridDirection;
-  OriginType          m_GridOrigin;
-  GridOffsetType      m_GridOffsetTable;
+  RegionType     m_GridRegion;
+  SpacingType    m_GridSpacing;
+  DirectionType  m_GridDirection;
+  OriginType     m_GridOrigin;
+  GridOffsetType m_GridOffsetTable;
 
-  DirectionType       m_PointToIndexMatrix;
-  SpatialJacobianType m_PointToIndexMatrix2;
-  DirectionType       m_PointToIndexMatrixTransposed;
-  SpatialJacobianType m_PointToIndexMatrixTransposed2;
-  DirectionType       m_IndexToPoint;
+  DirectionType                                       m_PointToIndexMatrix;
+  SpatialJacobianType                                 m_PointToIndexMatrix2;
+  DirectionType                                       m_PointToIndexMatrixTransposed;
+  SpatialJacobianType                                 m_PointToIndexMatrixTransposed2;
+  FixedArray< ScalarType, NDimensions >               m_PointToIndexMatrixDiagonal;
+  FixedArray< ScalarType, NDimensions * NDimensions > m_PointToIndexMatrixDiagonalProducts;
+  DirectionType                                       m_IndexToPoint;
+  bool                                                m_PointToIndexMatrixIsDiagonal;
 
-  RegionType          m_ValidRegion;
+  RegionType m_ValidRegion;
 
   /** Variables defining the interpolation support region. */
   unsigned long       m_Offset;
@@ -309,10 +333,10 @@ protected:
   bool m_SplineOrderOdd;
 
   /** Keep a pointer to the input parameters. */
-  const ParametersType *  m_InputParametersPointer;
+  const ParametersType * m_InputParametersPointer;
 
   /** Jacobian as SpaceDimension number of images. */
-  typedef typename JacobianType::ValueType      JacobianPixelType;
+  typedef typename JacobianType::ValueType JacobianPixelType;
   typedef Image< JacobianPixelType,
     itkGetStaticConstMacro( SpaceDimension ) >  JacobianImageType;
 
@@ -324,35 +348,24 @@ protected:
   mutable IndexType m_LastJacobianIndex;
 
   /** Array holding images wrapped from the flat parameters. */
-  ImagePointer      m_WrappedImage[ NDimensions ];
+  ImagePointer m_WrappedImage[ NDimensions ];
 
   /** Internal parameters buffer. */
-  ParametersType    m_InternalParametersBuffer;
+  ParametersType m_InternalParametersBuffer;
 
   void UpdateGridOffsetTable( void );
 
 private:
-  AdvancedBSplineDeformableTransformBase(const Self&); //purposely not implemented
-  void operator=(const Self&); //purposely not implemented
 
-}; //class AdvancedBSplineDeformableTransformBase
+  AdvancedBSplineDeformableTransformBase( const Self & ); // purposely not implemented
+  void operator=( const Self & );                         // purposely not implemented
 
+};
 
 }  // namespace itk
 
-// Define instantiation macro for this template.
-#define ITK_TEMPLATE_AdvancedBSplineDeformableTransformBase(_, EXPORT, x, y) namespace itk { \
-  _(3(class EXPORT AdvancedBSplineDeformableTransformBase< ITK_TEMPLATE_3 x >)) \
-  namespace Templates { typedef AdvancedBSplineDeformableTransformBase< ITK_TEMPLATE_3 x > \
-                                                   AdvancedBSplineDeformableTransformBase##y; } \
-  }
-
-#if ITK_TEMPLATE_EXPLICIT
-# include "Templates/itkAdvancedBSplineDeformableTransformBase+-.h"
-#endif
-
-#if ITK_TEMPLATE_TXX
-# include "itkAdvancedBSplineDeformableTransformBase.txx"
+#ifndef ITK_MANUAL_INSTANTIATION
+#include "itkAdvancedBSplineDeformableTransformBase.hxx"
 #endif
 
 #endif /* __itkAdvancedBSplineDeformableTransformBase_h */
