@@ -17,7 +17,7 @@
 #ifndef __itkBSplineKernelFunction2_h
 #define __itkBSplineKernelFunction2_h
 
-#include "itkKernelFunction.h"
+#include "itkKernelFunctionBase.h"
 #include "vnl/vnl_math.h"
 
 namespace itk
@@ -38,20 +38,21 @@ namespace itk
  *
  * \ingroup Functions
  */
-template <unsigned int VSplineOrder = 3>
-class ITK_EXPORT BSplineKernelFunction2 : public KernelFunction
+template< unsigned int VSplineOrder = 3 >
+class ITK_EXPORT BSplineKernelFunction2 : public KernelFunctionBase< double >
 {
 public:
+
   /** Standard class typedefs. */
-  typedef BSplineKernelFunction2  Self;
-  typedef KernelFunction          Superclass;
-  typedef SmartPointer<Self>      Pointer;
+  typedef BSplineKernelFunction2       Self;
+  typedef KernelFunctionBase< double > Superclass;
+  typedef SmartPointer< Self >         Pointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro( Self );
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( BSplineKernelFunction2, KernelFunction );
+  itkTypeMacro( BSplineKernelFunction2, KernelFunctionBase );
 
   /** Enum of for spline order. */
   itkStaticConstMacro( SplineOrder, unsigned int, VSplineOrder );
@@ -63,20 +64,23 @@ public:
   /** Evaluate the function at one point. */
   inline double Evaluate( const double & u ) const
   {
-    return this->Evaluate( Dispatch<VSplineOrder>(), u );
+    return this->Evaluate( Dispatch< VSplineOrder >(), u );
   }
 
+
   /** Evaluate the function at the entire support. This is slightly faster,
    * since no if's are needed.
    */
   inline void Evaluate( const double & u, WeightArrayType & weights ) const
   {
-    this->Evaluate( Dispatch<VSplineOrder>(), u, weights );
+    this->Evaluate( Dispatch< VSplineOrder >(), u, weights );
   }
 
+
 protected:
-  BSplineKernelFunction2(){};
-  ~BSplineKernelFunction2(){};
+
+  BSplineKernelFunction2(){}
+  ~BSplineKernelFunction2(){}
 
   void PrintSelf( std::ostream & os, Indent indent ) const
   {
@@ -84,13 +88,15 @@ protected:
     os << indent << "Spline Order: " << SplineOrder << std::endl;
   }
 
+
 private:
-  BSplineKernelFunction2(const Self&); //purposely not implemented
-  void operator=(const Self&); //purposely not implemented
+
+  BSplineKernelFunction2( const Self & ); //purposely not implemented
+  void operator=( const Self & );         //purposely not implemented
 
   /** Structures to control overloaded versions of Evaluate */
   struct DispatchBase {};
-  template<unsigned int>
+  template< unsigned int >
   struct Dispatch : DispatchBase {};
 
   /** *****************************************************
@@ -98,87 +104,94 @@ private:
    */
 
   /** Zeroth order spline. */
-  inline double Evaluate( const Dispatch<0> &, const double & u ) const
+  inline double Evaluate( const Dispatch< 0 > &, const double & u ) const
   {
     double absValue = vnl_math_abs( u );
 
-    if ( absValue < 0.5 ) return 1.0;
-    else if ( absValue == 0.5 ) return 0.5;
-    else return 0.0;
+    if( absValue < 0.5 ) { return 1.0; }
+    else if( absValue == 0.5 ) { return 0.5; }
+    else { return 0.0; }
   }
 
+
   /** First order spline */
-  inline double Evaluate( const Dispatch<1> &, const double & u ) const
+  inline double Evaluate( const Dispatch< 1 > &, const double & u ) const
   {
     double absValue = vnl_math_abs( u );
 
-    if ( absValue < 1.0 ) return 1.0 - absValue;
-    else return 0.0;
+    if( absValue < 1.0 ) { return 1.0 - absValue; }
+    else { return 0.0; }
   }
 
+
   /** Second order spline. */
-  inline double Evaluate( const Dispatch<2> &, const double & u ) const
+  inline double Evaluate( const Dispatch< 2 > &, const double & u ) const
   {
     double absValue = vnl_math_abs( u );
 
-    if ( absValue < 0.5 )
+    if( absValue < 0.5 )
     {
       return 0.75 - vnl_math_sqr( absValue );
     }
-    else if ( absValue < 1.5 )
+    else if( absValue < 1.5 )
     {
       return ( 9.0 - 12.0 * absValue + 4.0 * vnl_math_sqr( absValue ) ) / 8.0;
     }
-    else return 0.0;
+    else { return 0.0; }
   }
 
+
   /** Third order spline. */
-  inline double Evaluate( const Dispatch<3> &, const double & u ) const
+  inline double Evaluate( const Dispatch< 3 > &, const double & u ) const
   {
     double absValue = vnl_math_abs( u );
     double sqrValue = vnl_math_sqr( u );
 
-    if ( absValue < 1.0 )
+    if( absValue < 1.0 )
     {
       return ( 4.0 - 6.0 * sqrValue + 3.0 * sqrValue * absValue ) / 6.0;
     }
-    else if ( absValue < 2.0 )
+    else if( absValue < 2.0 )
     {
       return ( 8.0 - 12.0 * absValue + 6.0 * sqrValue - sqrValue * absValue ) / 6.0;
     }
-    else return 0.0;
+    else { return 0.0; }
   }
 
+
   /** Unimplemented spline order. */
   inline double Evaluate( const DispatchBase &, const double & ) const
   {
     itkExceptionMacro( << "Evaluate not implemented for spline order "
-      << SplineOrder );
+                       << SplineOrder );
     return 0.0;
   }
 
+
   /** *****************************************************
    * B-spline functions for all points in the support.
    */
 
   /** Zeroth order spline. */
-  inline void Evaluate( const Dispatch<0> &, const double & u,
+  inline void Evaluate( const Dispatch< 0 > &, const double & u,
     WeightArrayType & weights ) const
   {
-    if ( u < 0.5 ) weights[ 0 ] = 1.0;
-    else weights[ 0 ] = 0.5;
+    if( u < 0.5 ) { weights[ 0 ] = 1.0; }
+    else { weights[ 0 ] = 0.5; }
   }
 
+
   /** First order spline */
-  inline void Evaluate( const Dispatch<1> &, const double & u,
+  inline void Evaluate( const Dispatch< 1 > &, const double & u,
     WeightArrayType & weights ) const
   {
     weights[ 0 ] = 1.0 - u;
-    weights[ 1 ] = u - 1.0;
+    weights[ 1 ] = u;
   }
 
+
   /** Second order spline. */
-  inline void Evaluate( const Dispatch<2> &, const double & u,
+  inline void Evaluate( const Dispatch< 2 > &, const double & u,
     WeightArrayType & weights ) const
   {
     const double uu = vnl_math_sqr( u );
@@ -188,8 +201,9 @@ private:
     weights[ 2 ] = ( 1.0 - 4.0 * u + 4.0 * uu ) / 8.0;
   }
 
+
   /**  Third order spline. */
-  inline void Evaluate ( const Dispatch<3> &, const double & u,
+  inline void Evaluate( const Dispatch< 3 > &, const double & u,
     WeightArrayType & weights ) const
   {
     const double uu  = vnl_math_sqr( u );
@@ -201,17 +215,18 @@ private:
     weights[ 3 ] = ( -1.0 + 3.0 * u - 3.0 * uu + uuu ) / 6.0;
   }
 
+
   /** Unimplemented spline order. */
   inline double Evaluate( const DispatchBase &, const double &,
     WeightArrayType & ) const
   {
     itkExceptionMacro( << "Evaluate not implemented for spline order "
-      << SplineOrder );
+                       << SplineOrder );
     return 0.0;
   }
 
-};
 
+};
 
 } // end namespace itk
 
