@@ -43,7 +43,6 @@
 
 namespace tmr
 {
-using namespace itk;
 
 /**
  * \class Timer
@@ -64,37 +63,45 @@ using namespace itk;
  * \ingroup Timer
  */
 
-class Timer : public Object
+class Timer : public itk::Object
 {
 public:
+
   /** Standard ITK-stuff.*/
-  typedef Timer                       Self;
-  typedef Object                      Superclass;
-  typedef SmartPointer<Self>          Pointer;
-  typedef SmartPointer<const Self>    ConstPointer;
+  typedef Timer                           Self;
+  typedef itk::Object                     Superclass;
+  typedef itk::SmartPointer< Self >       Pointer;
+  typedef itk::SmartPointer< const Self > ConstPointer;
 
   /** Method for creation through the object factory.*/
   itkNewMacro( Self );
 
   /** Run-time type information (and related methods).*/
-  itkTypeMacro( Timer, Object );
+  itkTypeMacro( Timer, itk::Object );
 
   /** My typedef's.*/
-  typedef std::vector<std::size_t>         TimeDHMSType;
+  typedef std::vector< std::size_t > TimeDHMSType;
 
   /** Member functions.*/
   void StartTimer( void );
+
   int StopTimer( void );
+
   int ElapsedClockAndTime( void );
 
   /** Formatted Output Functions
    * (return the time as a string, with comments)
    */
   const std::string & PrintStartTime( void );
+
   const std::string & PrintStopTime( void );
+
   const std::string & PrintElapsedTimeDHMS( void );
+
   const std::string & PrintElapsedTimeSec( void );
+
   const std::string & PrintElapsedClock( void );
+
   const std::string & PrintElapsedClockSec( void );
 
   /** Communication with outside world.*/
@@ -109,21 +116,21 @@ public:
 protected:
 
   Timer();
-  virtual ~Timer(){};
+  virtual ~Timer(){}
 
   /** Variables that store program arguments.*/
-  time_t        m_StartTime;
-  clock_t       m_StartClock;
-  time_t        m_StopTime;
-  clock_t       m_StopClock;
-  double        m_ElapsedTime;
-  clock_t       m_ElapsedClock;
-  TimeDHMSType  m_ElapsedTimeDHMS;
-  std::size_t   m_ElapsedTimeSec;
-  double        m_ElapsedClockSec;
+  time_t       m_StartTime;
+  clock_t      m_StartClock;
+  time_t       m_StopTime;
+  clock_t      m_StopClock;
+  double       m_ElapsedTime;
+  clock_t      m_ElapsedClock;
+  TimeDHMSType m_ElapsedTimeDHMS;
+  std::size_t  m_ElapsedTimeSec;
+  double       m_ElapsedClockSec;
 
   /** GCC specific. We can use clock_gettime(). */
-#if defined( __GNUC__ ) && !defined( __APPLE__ )
+#if defined( __GNUC__ ) && !defined( __APPLE__ ) && !defined( _WIN32 )
 #define ELX_USE_CLOCK_GETTIME
   struct timespec m_StartClockMonotonic;
   struct timespec m_StopClockMonotonic;
@@ -139,13 +146,11 @@ protected:
 
 private:
 
-  Timer( const Self& );           // purposely not implemented
-  void operator=( const Self& );  // purposely not implemented
-
-}; // end class Timer
+  Timer( const Self & );           // purposely not implemented
+  void operator=( const Self & );  // purposely not implemented
 
+};
 
 } // end namespace tmr
 
-
 #endif // end #ifndef __elxTimer_H_
