@@ -11,17 +11,14 @@
      PURPOSE. See the above copyright notices for more information.
 
 ======================================================================*/
-
 #ifndef __elxMultiMetricMultiResolutionRegistration_H__
 #define __elxMultiMetricMultiResolutionRegistration_H__
 
+#include "elxIncludes.h" // include first to avoid MSVS warning
 #include "itkMultiMetricMultiResolutionImageRegistrationMethod.h"
 
-#include "elxIncludes.h"
-
 namespace elastix
 {
-using namespace itk;
 
 /**
  * \class MultiMetricMultiResolutionRegistration
@@ -91,29 +88,29 @@ using namespace itk;
  * \ingroup Registrations
  */
 
-template <class TElastix>
-class MultiMetricMultiResolutionRegistration
-  : public
-  MultiMetricMultiResolutionImageRegistrationMethod<
-  ITK_TYPENAME RegistrationBase<TElastix>::FixedImageType,
-  ITK_TYPENAME RegistrationBase<TElastix>::MovingImageType >,
-  public RegistrationBase<TElastix>
+template< class TElastix >
+class MultiMetricMultiResolutionRegistration :
+  public
+  itk::MultiMetricMultiResolutionImageRegistrationMethod<
+  typename RegistrationBase< TElastix >::FixedImageType,
+  typename RegistrationBase< TElastix >::MovingImageType >,
+  public RegistrationBase< TElastix >
 {
 public:
 
   /** Standard ITK: Self */
-  typedef MultiMetricMultiResolutionRegistration      Self;
+  typedef MultiMetricMultiResolutionRegistration Self;
 
   /** Standard ITK: Superclasses. */
-  typedef MultiMetricMultiResolutionImageRegistrationMethod<
-    typename RegistrationBase<TElastix>::FixedImageType,
-    typename RegistrationBase<TElastix>::MovingImageType >
-                                                      Superclass1;
-  typedef RegistrationBase<TElastix>                  Superclass2;
+  typedef itk::MultiMetricMultiResolutionImageRegistrationMethod<
+    typename RegistrationBase< TElastix >::FixedImageType,
+    typename RegistrationBase< TElastix >::MovingImageType >
+    Superclass1;
+  typedef RegistrationBase< TElastix > Superclass2;
 
   /** Standard ITK: SmartPointers */
-  typedef SmartPointer<Self>                          Pointer;
-  typedef SmartPointer<const Self>                    ConstPointer;
+  typedef itk::SmartPointer< Self >       Pointer;
+  typedef itk::SmartPointer< const Self > ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro( Self );
@@ -131,55 +128,55 @@ public:
   /** Typedef's inherited from Superclass1. */
 
   /**  Type of the Fixed image. */
-  typedef typename Superclass1::FixedImageType            FixedImageType;
-  typedef typename Superclass1::FixedImageConstPointer    FixedImageConstPointer;
-  typedef typename Superclass1::FixedImageRegionType      FixedImageRegionType;
+  typedef typename Superclass1::FixedImageType         FixedImageType;
+  typedef typename Superclass1::FixedImageConstPointer FixedImageConstPointer;
+  typedef typename Superclass1::FixedImageRegionType   FixedImageRegionType;
 
   /**  Type of the Moving image. */
-  typedef typename Superclass1::MovingImageType           MovingImageType;
-  typedef typename Superclass1::MovingImageConstPointer   MovingImageConstPointer;
+  typedef typename Superclass1::MovingImageType         MovingImageType;
+  typedef typename Superclass1::MovingImageConstPointer MovingImageConstPointer;
 
   /**  Type of the metric. */
-  typedef typename Superclass1::MetricType                MetricType;
-  typedef typename Superclass1::MetricPointer             MetricPointer;
+  typedef typename Superclass1::MetricType    MetricType;
+  typedef typename Superclass1::MetricPointer MetricPointer;
 
   /**  Type of the Transform . */
-  typedef typename Superclass1::TransformType             TransformType;
-  typedef typename Superclass1::TransformPointer          TransformPointer;
+  typedef typename Superclass1::TransformType    TransformType;
+  typedef typename Superclass1::TransformPointer TransformPointer;
 
   /**  Type of the Interpolator. */
-  typedef typename Superclass1::InterpolatorType          InterpolatorType;
-  typedef typename Superclass1::InterpolatorPointer       InterpolatorPointer;
+  typedef typename Superclass1::InterpolatorType    InterpolatorType;
+  typedef typename Superclass1::InterpolatorPointer InterpolatorPointer;
 
   /**  Type of the optimizer. */
-  typedef typename Superclass1::OptimizerType             OptimizerType;
-  typedef typename Superclass1::OptimizerPointer          OptimizerPointer;
+  typedef typename Superclass1::OptimizerType    OptimizerType;
+  typedef typename Superclass1::OptimizerPointer OptimizerPointer;
 
   /** Type of the Fixed image multiresolution pyramid. */
-  typedef typename Superclass1::FixedImagePyramidType     FixedImagePyramidType;
-  typedef typename Superclass1::FixedImagePyramidPointer  FixedImagePyramidPointer;
+  typedef typename Superclass1::FixedImagePyramidType    FixedImagePyramidType;
+  typedef typename Superclass1::FixedImagePyramidPointer FixedImagePyramidPointer;
 
   /** Type of the moving image multiresolution pyramid. */
-  typedef typename Superclass1::MovingImagePyramidType    MovingImagePyramidType ;
+  typedef typename Superclass1::MovingImagePyramidType    MovingImagePyramidType;
   typedef typename Superclass1::MovingImagePyramidPointer MovingImagePyramidPointer;
 
   /** Type of the Transformation parameters. This is the same type used to
    *  represent the search space of the optimization algorithm.
    */
-  typedef typename Superclass1::ParametersType            ParametersType;
+  typedef typename Superclass1::ParametersType ParametersType;
 
   /** The CombinationMetric type, which is used internally by the Superclass1. */
-  typedef typename Superclass1::CombinationMetricType     CombinationMetricType;
-  typedef typename Superclass1::CombinationMetricPointer  CombinationMetricPointer;
+  typedef typename Superclass1::CombinationMetricType    CombinationMetricType;
+  typedef typename Superclass1::CombinationMetricPointer CombinationMetricPointer;
 
   /** Typedef's from Elastix. */
-  typedef typename Superclass2::ElastixType           ElastixType;
-  typedef typename Superclass2::ElastixPointer        ElastixPointer;
-  typedef typename Superclass2::ConfigurationType     ConfigurationType;
-  typedef typename Superclass2::ConfigurationPointer  ConfigurationPointer;
-  typedef typename Superclass2::RegistrationType      RegistrationType;
-  typedef typename Superclass2::RegistrationPointer   RegistrationPointer;
-  typedef typename Superclass2::ITKBaseType           ITKBaseType;
+  typedef typename Superclass2::ElastixType             ElastixType;
+  typedef typename Superclass2::ElastixPointer          ElastixPointer;
+  typedef typename Superclass2::ConfigurationType       ConfigurationType;
+  typedef typename Superclass2::ConfigurationPointer    ConfigurationPointer;
+  typedef typename Superclass2::RegistrationType        RegistrationType;
+  typedef typename Superclass2::RegistrationPointer     RegistrationPointer;
+  typedef typename Superclass2::ITKBaseType             ITKBaseType;
   typedef typename Superclass2::UseMaskErosionArrayType UseMaskErosionArrayType;
 
   /** Get the dimension of the fixed image. */
@@ -211,26 +208,27 @@ protected:
   /** The constructor. */
   MultiMetricMultiResolutionRegistration();
   /** The destructor. */
-  virtual ~MultiMetricMultiResolutionRegistration() {};
+  virtual ~MultiMetricMultiResolutionRegistration() {}
 
   /** Typedef for timer.*/
-  typedef tmr::Timer          TimerType;
+  typedef tmr::Timer TimerType;
   /** Typedef for timer.*/
-  typedef TimerType::Pointer  TimerPointer;
+  typedef TimerType::Pointer TimerPointer;
 
   /** Typedef's for mask support. */
-  typedef typename Superclass2::MaskPixelType                   MaskPixelType;
-  typedef typename Superclass2::FixedMaskImageType              FixedMaskImageType;
-  typedef typename Superclass2::MovingMaskImageType             MovingMaskImageType;
-  typedef typename Superclass2::FixedMaskImagePointer           FixedMaskImagePointer;
-  typedef typename Superclass2::MovingMaskImagePointer          MovingMaskImagePointer;
-  typedef typename Superclass2::FixedMaskSpatialObjectType      FixedMaskSpatialObjectType;
-  typedef typename Superclass2::MovingMaskSpatialObjectType     MovingMaskSpatialObjectType;
-  typedef typename Superclass2::FixedMaskSpatialObjectPointer   FixedMaskSpatialObjectPointer;
-  typedef typename Superclass2::MovingMaskSpatialObjectPointer  MovingMaskSpatialObjectPointer;
+  typedef typename Superclass2::MaskPixelType                  MaskPixelType;
+  typedef typename Superclass2::FixedMaskImageType             FixedMaskImageType;
+  typedef typename Superclass2::MovingMaskImageType            MovingMaskImageType;
+  typedef typename Superclass2::FixedMaskImagePointer          FixedMaskImagePointer;
+  typedef typename Superclass2::MovingMaskImagePointer         MovingMaskImagePointer;
+  typedef typename Superclass2::FixedMaskSpatialObjectType     FixedMaskSpatialObjectType;
+  typedef typename Superclass2::MovingMaskSpatialObjectType    MovingMaskSpatialObjectType;
+  typedef typename Superclass2::FixedMaskSpatialObjectPointer  FixedMaskSpatialObjectPointer;
+  typedef typename Superclass2::MovingMaskSpatialObjectPointer MovingMaskSpatialObjectPointer;
 
   /** Function to update masks. */
   void UpdateFixedMasks( unsigned int level );
+
   void UpdateMovingMasks( unsigned int level );
 
   /** Read the components from m_Elastix and set them in the Registration class. */
@@ -241,12 +239,11 @@ protected:
 private:
 
   /** The private constructor. */
-  MultiMetricMultiResolutionRegistration( const Self& );  // purposely not implemented
+  MultiMetricMultiResolutionRegistration( const Self & );  // purposely not implemented
   /** The private copy constructor. */
-  void operator=( const Self& );              // purposely not implemented
-
-}; // end class MultiMetricMultiResolutionRegistration
+  void operator=( const Self & );              // purposely not implemented
 
+};
 
 } // end namespace elastix
 
