@@ -29,17 +29,19 @@ namespace itk
  *
  * \ingroup Transforms
  */
-template <class TScalarType,         // Data type for scalars (float or double)
-          unsigned int NDimensions = 3>          // Number of dimensions
-class ITK_EXPORT VolumeSplineKernelTransform2 :
-                public KernelTransform2<   TScalarType, NDimensions>
+template< class TScalarType,         // Data type for scalars (float or double)
+unsigned int NDimensions = 3 >
+// Number of dimensions
+class VolumeSplineKernelTransform2 :
+  public KernelTransform2<   TScalarType, NDimensions >
 {
 public:
+
   /** Standard class typedefs. */
   typedef VolumeSplineKernelTransform2                 Self;
-  typedef KernelTransform2<TScalarType, NDimensions>   Superclass;
-  typedef SmartPointer<Self>                          Pointer;
-  typedef SmartPointer<const Self>                    ConstPointer;
+  typedef KernelTransform2< TScalarType, NDimensions > Superclass;
+  typedef SmartPointer< Self >                         Pointer;
+  typedef SmartPointer< const Self >                   ConstPointer;
 
   /** New macro for creation of through a Smart Pointer */
   itkNewMacro( Self );
@@ -48,35 +50,37 @@ public:
   itkTypeMacro( VolumeSplineKernelTransform2, KernelTransform2 );
 
   /** Scalar type. */
-  typedef typename Superclass::ScalarType  ScalarType;
+  typedef typename Superclass::ScalarType ScalarType;
 
   /** Parameters type. */
-  typedef typename Superclass::ParametersType  ParametersType;
+  typedef typename Superclass::ParametersType ParametersType;
 
   /** Jacobian Type */
-  typedef typename Superclass::JacobianType  JacobianType;
+  typedef typename Superclass::JacobianType JacobianType;
 
   /** Dimension of the domain space. */
-  itkStaticConstMacro(SpaceDimension, unsigned int,Superclass::SpaceDimension);
+  itkStaticConstMacro( SpaceDimension, unsigned int, Superclass::SpaceDimension );
 
   /** These (rather redundant) typedefs are needed because on SGI, typedefs
    * are not inherited */
-  typedef typename Superclass::InputPointType     InputPointType;
-  typedef typename Superclass::OutputPointType    OutputPointType;
-  typedef typename Superclass::InputVectorType    InputVectorType;
-  typedef typename Superclass::OutputVectorType   OutputVectorType;
+  typedef typename Superclass::InputPointType   InputPointType;
+  typedef typename Superclass::OutputPointType  OutputPointType;
+  typedef typename Superclass::InputVectorType  InputVectorType;
+  typedef typename Superclass::OutputVectorType OutputVectorType;
   typedef typename Superclass::InputCovariantVectorType
-                                                  InputCovariantVectorType;
+    InputCovariantVectorType;
   typedef typename Superclass::OutputCovariantVectorType
-                                                  OutputCovariantVectorType;
-  typedef typename Superclass::PointsIterator     PointsIterator;
-
+    OutputCovariantVectorType;
+  typedef typename Superclass::PointsIterator PointsIterator;
 
 protected:
+
   VolumeSplineKernelTransform2()
   {
     this->m_FastComputationPossible = true;
-  };
+  }
+
+
   virtual ~VolumeSplineKernelTransform2() {}
 
   /** These (rather redundant) typedefs are needed because on SGI, typedefs
@@ -91,24 +95,24 @@ protected:
    * r(x) = Euclidean norm = sqrt[x1^2 + x2^2 + x3^2]
    * \f[ r(x) = \sqrt{ x_1^2 + x_2^2 + x_3^2 }  \f]
    * I = identity matrix. */
-  void ComputeG(const InputVectorType & x, GMatrixType & GMatrix) const;
-
+  void ComputeG( const InputVectorType & x, GMatrixType & GMatrix ) const;
 
   /** Compute the contribution of the landmarks weighted by the kernel funcion
       to the global deformation of the space  */
-  virtual void ComputeDeformationContribution(const InputPointType & inputPoint,
-                                              OutputPointType & result ) const;
+  virtual void ComputeDeformationContribution( const InputPointType & inputPoint,
+    OutputPointType & result ) const;
 
 private:
-  VolumeSplineKernelTransform2(const Self&); //purposely not implemented
-  void operator=(const Self&); //purposely not implemented
+
+  VolumeSplineKernelTransform2( const Self & ); // purposely not implemented
+  void operator=( const Self & );               // purposely not implemented
 
 };
 
 } // namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkVolumeSplineKernelTransform2.txx"
+#include "itkVolumeSplineKernelTransform2.hxx"
 #endif
 
 #endif // __itkVolumeSplineKernelTransform2_h
