@@ -11,10 +11,18 @@
      PURPOSE. See the above copyright notices for more information.
 
 ======================================================================*/
-
 #ifndef __elxMacro_h
 #define __elxMacro_h
 
+/** This include is only used to get rid of a MSVS compiler warning
+ * when using std::copy. The warning is like:
+ *   'conversion' conversion from 'type1' to 'type2', possible loss of data
+ * To solve it ITK recommends to include itkMacro.h before <algorithm> or
+ * any other stl header. In elastix we try to make sure that elxIncludes.h
+ * is included before anything else, which includes elxMacro.h, which now
+ * includes itkWin32Header.h.
+ */
+#include "itkWin32Header.h"
 
 /**
  * Macro for installing support new components
@@ -77,37 +85,36 @@
  * supported image types).
  *
  */
-#define elxInstallMacro(_classname) \
-  template < ::elx::ComponentDatabase::IndexType VIndex> \
-    class _classname##_install \
+#define elxInstallMacro( _classname ) \
+  template< ::elx::ComponentDatabase::IndexType VIndex > \
+  class _classname##_install \
   { \
-  public: \
-    typedef typename ::elx::ElastixTypedef<VIndex>::ElastixType ElastixType; \
-    typedef ::elx::ComponentDatabase::ComponentDescriptionType ComponentDescriptionType; \
-    static int DO(::elx::ComponentDatabase * cdb) \
+public: \
+    typedef typename::elx::ElastixTypedef< VIndex >::ElastixType ElastixType; \
+    typedef::elx::ComponentDatabase::ComponentDescriptionType    ComponentDescriptionType; \
+    static int DO( ::elx::ComponentDatabase * cdb ) \
     { \
-    ComponentDescriptionType name = ::elx:: _classname <ElastixType>::elxGetClassNameStatic(); \
-    int dummy = ::elx::InstallFunctions< ::elx:: _classname <ElastixType> >::InstallComponent(name, VIndex, cdb); \
-      if ( ::elx::ElastixTypedef<VIndex+1>::Defined() ) \
-      { return _classname##_install<VIndex+1>::DO( cdb ); } \
+      ComponentDescriptionType name  = ::elx::_classname< ElastixType >::elxGetClassNameStatic(); \
+      int                      dummy = ::elx::InstallFunctions< ::elx::_classname< ElastixType > >::InstallComponent( name, VIndex, cdb ); \
+      if( ::elx::ElastixTypedef< VIndex + 1 >::Defined() ) \
+      { return _classname##_install< VIndex + 1 >::DO( cdb ); } \
       return dummy;  \
     } \
   }; \
-  template <> \
-    class _classname##_install < ::elx::NrOfSupportedImageTypes+1 > \
+  template< > \
+  class _classname##_install< ::elx::NrOfSupportedImageTypes + 1 > \
   { \
-  public: \
-    typedef ::elx::ComponentDatabase::ComponentDescriptionType ComponentDescriptionType; \
-    static int DO(::elx::ComponentDatabase * /** cdb */ ) \
+public: \
+    typedef::elx::ComponentDatabase::ComponentDescriptionType ComponentDescriptionType; \
+    static int DO( ::elx::ComponentDatabase * /** cdb */ ) \
     { return 0; } \
   }; \
   extern "C" int _classname##InstallComponent( \
-    ::elx::ComponentDatabase * _cdb ) \
+  ::elx::ComponentDatabase * _cdb ) \
   { \
-    int _InstallDummy##_classname = _classname##_install<1>::DO( _cdb  ); \
-    return _InstallDummy##_classname ; \
-  }//ignore semicolon
-
+    int _InstallDummy##_classname = _classname##_install< 1 >::DO( _cdb  ); \
+    return _InstallDummy##_classname; \
+  } //ignore semicolon
 
 /**
  * elxInstallComponentFunctionDeclarationMacro
@@ -126,10 +133,9 @@
  *
  * See also elxInstallAllComponents.h.
  */
-#define elxInstallComponentFunctionDeclarationMacro(_classname)\
-extern "C" int _classname##InstallComponent( \
-    ::elx::ComponentDatabase * _cdb )
-
+#define elxInstallComponentFunctionDeclarationMacro( _classname ) \
+  extern "C" int _classname##InstallComponent( \
+  ::elx::ComponentDatabase * _cdb )
 
 /**
  * elxInstallComponentFunctionCallMacro
@@ -148,10 +154,9 @@ extern "C" int _classname##InstallComponent( \
  *
  * See also elxInstallAllComponents.h.
  */
-#define elxInstallComponentFunctionCallMacro(_classname)\
+#define elxInstallComponentFunctionCallMacro( _classname ) \
   ret |= _classname##InstallComponent( _cdb )
 
-
 /**
  * elxPrepareImageTypeSupportMacro
  * To be called once, before the elxSupportImageTypeMacro()
@@ -160,29 +165,29 @@ extern "C" int _classname##InstallComponent( \
  */
 
 #define elxPrepareImageTypeSupportMacro() \
-  template < ::elx::ComponentDatabase::IndexType VIndex >  /**unsigned int*/ \
-    class ElastixTypedef \
+  template< ::elx::ComponentDatabase::IndexType VIndex > \
+  /**unsigned int*/ \
+  class ElastixTypedef \
   { \
-  public: \
+public: \
     /** In the specialisations of this template class */ \
     /** this typedef will make sense */ \
-    typedef ::itk::Object ElastixType;  \
-    typedef ::elx::ComponentDatabase::PixelTypeDescriptionType PixelTypeString; \
-    static PixelTypeString fPixelTypeAsString(void) \
-      { return PixelTypeString("");} \
-    static PixelTypeString mPixelTypeAsString(void) \
-      { return PixelTypeString("");} \
-    static unsigned int fDim(void) \
-      { return 0;} \
-    static unsigned int mDim(void) \
-      { return 0;} \
+    typedef::itk::Object                                      ElastixType;  \
+    typedef::elx::ComponentDatabase::PixelTypeDescriptionType PixelTypeString; \
+    static PixelTypeString fPixelTypeAsString( void ) \
+    { return PixelTypeString( "" ); } \
+    static PixelTypeString mPixelTypeAsString( void ) \
+    { return PixelTypeString( "" ); } \
+    static unsigned int fDim( void ) \
+    { return 0; } \
+    static unsigned int mDim( void ) \
+    { return 0; } \
     /** In the specialisations of this template class*/ \
     /** this function will return 'true' */ \
-    static bool Defined(void) \
-      { return false;} \
+    static bool Defined( void ) \
+    { return false; } \
   }
 
-
 /**
  * Macro for installing support for new ImageTypes.
  * Used in elxSupportedImageTypes.cxx .
@@ -210,28 +215,27 @@ extern "C" int _classname##InstallComponent( \
  *
  */
 
-#define elxSupportedImageTypeMacro(_fPixelType,_fDim,_mPixelType,_mDim,_VIndex) \
-  template<> \
-    class ElastixTypedef < _VIndex > \
+#define elxSupportedImageTypeMacro( _fPixelType, _fDim, _mPixelType, _mDim, _VIndex ) \
+  template< > \
+  class ElastixTypedef< _VIndex > \
   { \
-  public: \
-    typedef ::itk::Image< _fPixelType , _fDim > FixedImageType; \
-    typedef ::itk::Image< _mPixelType , _mDim > MovingImageType; \
-    typedef ::elx::ElastixTemplate< FixedImageType, MovingImageType > ElastixType; \
-    typedef ::elx::ComponentDatabase::PixelTypeDescriptionType PixelTypeString; \
-    static PixelTypeString fPixelTypeAsString(void) \
-      { return PixelTypeString( #_fPixelType );} \
-    static PixelTypeString mPixelTypeAsString(void) \
-      { return PixelTypeString( #_mPixelType );} \
-    static unsigned int fDim(void) \
-      { return _fDim ;} \
-    static unsigned int mDim(void) \
-      { return _mDim ;} \
-    static bool Defined(void) \
+public: \
+    typedef::itk::Image< _fPixelType, _fDim >                        FixedImageType; \
+    typedef::itk::Image< _mPixelType, _mDim >                        MovingImageType; \
+    typedef::elx::ElastixTemplate< FixedImageType, MovingImageType > ElastixType; \
+    typedef::elx::ComponentDatabase::PixelTypeDescriptionType        PixelTypeString; \
+    static PixelTypeString fPixelTypeAsString( void ) \
+    { return PixelTypeString( #_fPixelType ); } \
+    static PixelTypeString mPixelTypeAsString( void ) \
+    { return PixelTypeString( #_mPixelType ); } \
+    static unsigned int fDim( void ) \
+    { return _fDim; } \
+    static unsigned int mDim( void ) \
+    { return _mDim; } \
+    static bool Defined( void ) \
     { return true; }  \
   }
 
-
 /**
  * elxClassNameMacro(_name)
  *
@@ -251,10 +255,9 @@ extern "C" int _classname##InstallComponent( \
  * Use this macro in every component that will be installed in the
  * ComponentDatabase, using "elxInstallMacro".
  */
-#define elxClassNameMacro(_name) \
-static const char * elxGetClassNameStatic( void ) { return _name ; } \
-virtual const char * elxGetClassName( void ) const { return _name ; }
-
+#define elxClassNameMacro( _name ) \
+  static const char * elxGetClassNameStatic( void ) { return _name; } \
+  virtual const char * elxGetClassName( void ) const { return _name; }
 
 /**
  *  elxout
@@ -267,8 +270,6 @@ virtual const char * elxGetClassName( void ) const { return _name ; }
  *  xout["{error, warning, etc}"].
  *
  */
-#define elxout ::xl::xout["standard"]
-
+#define elxout ::xl::xout[ "standard" ]
 
 #endif // end #ifndef __elxMacro_h
-
