@@ -16,7 +16,7 @@
  *  This is to set the priority, but which does not work on cygwin.
  */
 
-#if defined(_WIN32) && !defined(__CYGWIN__)
+#if defined( _WIN32 ) && !defined( __CYGWIN__ )
   #include <windows.h>
 #endif
 
@@ -33,7 +33,8 @@ namespace elastix
  * or that m_Configuration is initialised in another way.
  */
 
-int TransformixMain::Run( void )
+int
+TransformixMain::Run( void )
 {
   /** Set process properties. */
   this->SetProcessPriority();
@@ -41,7 +42,7 @@ int TransformixMain::Run( void )
 
   /** Initialize database. */
   int errorCode = this->InitDBIndex();
-  if ( errorCode != 0 )
+  if( errorCode != 0 )
   {
     return errorCode;
   }
@@ -52,14 +53,18 @@ int TransformixMain::Run( void )
     /** Key "Elastix", see elxComponentLoader::InstallSupportedImageTypes(). */
     this->m_Elastix = this->CreateComponent( "Elastix" );
   }
-  catch ( itk::ExceptionObject & excp )
+  catch( itk::ExceptionObject & excp )
   {
-    /** We just print the exception and let the programm quit. */
-    xl::xout["error"] << excp << std::endl;
+    /** We just print the exception and let the program quit. */
+    xl::xout[ "error" ] << excp << std::endl;
     errorCode = 1;
     return errorCode;
   }
 
+#ifdef _ELASTIX_BUILD_LIBRARY
+  this->GetElastixBase()->SetConfigurations( this->m_Configurations );
+#endif // #ifdef _ELASTIX_BUILD_LIBRARY
+
   /** Set some information in the ElastixBase. */
   this->GetElastixBase()->SetConfiguration( this->m_Configuration );
   this->GetElastixBase()->SetComponentDatabase( this->s_CDB );
@@ -77,10 +82,10 @@ int TransformixMain::Run( void )
     this->CreateComponents( "Transform", "", errorCode ) );
 
   /** Check if all components could be created. */
-  if ( errorCode != 0 )
+  if( errorCode != 0 )
   {
-    xl::xout["error"] << "ERROR:" << std::endl;
-    xl::xout["error"] << "One or more components could not be created." << std::endl;
+    xl::xout[ "error" ] << "ERROR:" << std::endl;
+    xl::xout[ "error" ] << "One or more components could not be created." << std::endl;
     return 1;
   }
 
@@ -103,16 +108,18 @@ int TransformixMain::Run( void )
   catch( itk::ExceptionObject & excp )
   {
     /** We just print the exception and let the program quit. */
-    xl::xout["error"] << std::endl
-      << "--------------- Exception ---------------"
-      << std::endl << excp
-      << "-----------------------------------------" << std::endl;
+    xl::xout[ "error" ] << std::endl
+                        << "--------------- Exception ---------------"
+                        << std::endl << excp
+                        << "-----------------------------------------" << std::endl;
     errorCode = 1;
   }
 
   /** Save the image container. */
   this->SetMovingImageContainer(
     this->GetElastixBase()->GetMovingImageContainer() );
+  this->SetResultImageContainer(
+    this->GetElastixBase()->GetResultImageContainer() );
 
   return errorCode;
 
@@ -121,15 +128,41 @@ int TransformixMain::Run( void )
 
 /**
  * **************************** Run *****************************
- *
- * Calls EnterCommandLineParameters and then Run().
  */
 
-int TransformixMain::Run( ArgumentMapType & argmap )
+int
+TransformixMain::Run( ArgumentMapType & argmap )
 {
   this->EnterCommandLineArguments( argmap );
   return this->Run();
+} // end Run()
 
+
+/**
+ * **************************** Run *****************************
+ */
+
+int
+TransformixMain::Run(
+  ArgumentMapType & argmap,
+  ParameterMapType & inputMap )
+{
+  this->EnterCommandLineArguments( argmap, inputMap );
+  return this->Run();
+} // end Run()
+
+
+/**
+ * **************************** Run *****************************
+ */
+
+int
+TransformixMain::Run(
+  ArgumentMapType & argmap,
+  std::vector< ParameterMapType > & inputMaps )
+{
+  this->EnterCommandLineArguments( argmap, inputMaps );
+  return this->Run();
 } // end Run()
 
 
@@ -137,7 +170,8 @@ int TransformixMain::Run( ArgumentMapType & argmap )
  * ********************* SetInputImage **************************
  */
 
-void TransformixMain::SetInputImageContainer(
+void
+TransformixMain::SetInputImageContainer(
   DataObjectContainerType * inputImageContainer )
 {
   /** InputImage == MovingImage. */
@@ -150,63 +184,64 @@ void TransformixMain::SetInputImageContainer(
  * ********************* InitDBIndex ****************************
  */
 
-int TransformixMain::InitDBIndex( void )
+int
+TransformixMain::InitDBIndex( void )
 {
   /** Check if configuration object was already initialized. */
-  if ( this->m_Configuration->IsInitialized() )
+  if( this->m_Configuration->IsInitialized() )
   {
     /** Try to read MovingImagePixelType from the parameter file. */
-    this->m_MovingImagePixelType = "float";
+    this->m_MovingImagePixelType = "float"; // \note: this assumes elastix was compiled for float
     this->m_Configuration->ReadParameter( this->m_MovingImagePixelType,
       "MovingInternalImagePixelType", 0 );
 
     /** Try to read FixedImagePixelType from the parameter file. */
-    this->m_FixedImagePixelType = "float";
+    this->m_FixedImagePixelType = "float"; // \note: this assumes elastix was compiled for float
     this->m_Configuration->ReadParameter( this->m_FixedImagePixelType,
       "FixedInternalImagePixelType", 0 );
 
     /** MovingImageDimension. */
-    if ( this->m_MovingImageDimension == 0 )
+    if( this->m_MovingImageDimension == 0 )
     {
-      /** Try to read it from the parameter file. */
+      /** Try to read it from the transform parameter file. */
       this->m_Configuration->ReadParameter( this->m_MovingImageDimension,
         "MovingImageDimension", 0 );
 
-      if ( this->m_MovingImageDimension == 0 )
+      if( this->m_MovingImageDimension == 0 )
       {
-        xl::xout["error"] << "ERROR:" << std::endl;
-        xl::xout["error"] << "The MovingImageDimension is not given." << std::endl;
+        xl::xout[ "error" ] << "ERROR:" << std::endl;
+        xl::xout[ "error" ] << "The MovingImageDimension is not given." << std::endl;
         return 1;
       }
     }
 
     /** FixedImageDimension. */
-    if ( this->m_FixedImageDimension == 0 )
+    if( this->m_FixedImageDimension == 0 )
     {
-      /** Try to read it from the parameter file. */
+      /** Try to read it from the transform parameter file. */
       this->m_Configuration->ReadParameter( this->m_FixedImageDimension,
         "FixedImageDimension", 0 );
 
-      if ( this->m_FixedImageDimension == 0 )
+      if( this->m_FixedImageDimension == 0 )
       {
-        xl::xout["error"] << "ERROR:" << std::endl;
-        xl::xout["error"] << "The FixedImageDimension is not given." << std::endl;
+        xl::xout[ "error" ] << "ERROR:" << std::endl;
+        xl::xout[ "error" ] << "The FixedImageDimension is not given." << std::endl;
         return 1;
       }
     }
 
     /** Load the components. */
-    if ( this->s_CDB.IsNull() )
+    if( this->s_CDB.IsNull() )
     {
       int loadReturnCode = this->LoadComponents();
-      if ( loadReturnCode !=0 )
+      if( loadReturnCode != 0 )
       {
-        xl::xout["error"] << "Loading components failed" << std::endl;
+        xl::xout[ "error" ] << "Loading components failed" << std::endl;
         return loadReturnCode;
       }
     }
 
-    if ( this->s_CDB.IsNotNull() )
+    if( this->s_CDB.IsNotNull() )
     {
       /** Get the DBIndex from the ComponentDatabase. */
       this->m_DBIndex = this->s_CDB->GetIndex(
@@ -214,10 +249,10 @@ int TransformixMain::InitDBIndex( void )
         this->m_FixedImageDimension,
         this->m_MovingImagePixelType,
         this->m_MovingImageDimension );
-      if ( this->m_DBIndex == 0 )
+      if( this->m_DBIndex == 0 )
       {
-        xl::xout["error"] << "ERROR:" << std::endl;
-        xl::xout["error"] << "Something went wrong in the ComponentDatabase." << std::endl;
+        xl::xout[ "error" ] << "ERROR:" << std::endl;
+        xl::xout[ "error" ] << "Something went wrong in the ComponentDatabase." << std::endl;
         return 1;
       }
     } //end if s_CDB!=0
@@ -225,8 +260,8 @@ int TransformixMain::InitDBIndex( void )
   } // end if m_Configuration->Initialized();
   else
   {
-    xl::xout["error"] << "ERROR:" << std::endl;
-    xl::xout["error"] << "The configuration object has not been initialized." << std::endl;
+    xl::xout[ "error" ] << "ERROR:" << std::endl;
+    xl::xout[ "error" ] << "The configuration object has not been initialized." << std::endl;
     return 1;
   }
 
@@ -237,4 +272,3 @@ int TransformixMain::InitDBIndex( void )
 
 
 } // end namespace elastix
-
