@@ -15,9 +15,7 @@
 #ifndef __transformix_h
 #define __transformix_h
 
-#ifdef _ELASTIX_USE_MEVISDICOMTIFF
-  #include "itkUseMevisDicomTiff.h"
-#endif
+#include "itkUseMevisDicomTiff.h"
 
 #include "elxTransformixMain.h"
 #include <iostream>
@@ -33,7 +31,6 @@
 #include "elxTimer.h"
 
 /** Declare PrintHelp function.*/
-void PrintHelp(void);
+void PrintHelp( void );
 
 #endif // end #ifndef __transformix_h
-
